Index: trunk/src/tmcsim/cadsimulator/CADClientConnector.java
===================================================================
--- trunk/src/tmcsim/cadsimulator/CADClientConnector.java	(revision 660)
+++ trunk/src/tmcsim/cadsimulator/CADClientConnector.java	(revision 664)
@@ -107,4 +107,9 @@
         catch (ClassNotFoundException cnfe) {
             cnfe.printStackTrace();
+        }
+        catch (java.io.EOFException except)
+        {
+            cadLogger.logp(Level.INFO, "CADClientConnector", "run", "Client appears to have shutdown, removing client.\n");
+            disconnectClient();
         }
         catch (SocketException except)
Index: trunk/src/tmcsim/cadsimulator/viewer/ConfigStatusTab.java
===================================================================
--- trunk/src/tmcsim/cadsimulator/viewer/ConfigStatusTab.java	(revision 455)
+++ trunk/src/tmcsim/cadsimulator/viewer/ConfigStatusTab.java	(revision 664)
@@ -132,5 +132,5 @@
         frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
         frame.setSize(1050, 450);
-        ConfigStatusTab pnl = new ConfigStatusTab("config/cad_simulator_config.properties");
+        ConfigStatusTab pnl = new ConfigStatusTab("config/cad_server.properties");
         frame.add(pnl);
         frame.setVisible(true);
Index: trunk/src/tmcsim/cadsimulator/CADServer.java
===================================================================
--- trunk/src/tmcsim/cadsimulator/CADServer.java	(revision 654)
+++ trunk/src/tmcsim/cadsimulator/CADServer.java	(revision 664)
@@ -27,41 +27,18 @@
 
 /**
  * CADSimulator is main class for the CAD Simulator application. At construction
  * the Coordinator, CoordinatorViewer, and all CAD Simulator Managers are
  * initialized and data relationships are established. Simulation control is
  * managed through the Coordinator and Managers. The CADSimulator contains the
  * instances of all Manager Objects that are used to control the Simulation flow
  * of data.<br>
+ * There is a GUI (and for testing, a text-based UI) that displays the state
+ * of the server.
  * <br>
+ * A properties file contains settings for many parameters of the CADServer<br>
  *
- * The CADSimulator is initialized with a properties file containing the
- * following data items:<br>
- * <code>
- * -----------------------------------------------------------------------------<br>
- * CADClientPort The port number to use for remote CAD Client connections.<br>
- * CoordinatorRMIPort The port number to use for binding the Coordinator.<br>
- * CMSDiversionXML The filepath for the xml file containing initialization data
- * for the Diversion "database." AudioFileLocation The root directory path where
- * audio files are referenced from.<br>
- * ParamicsProperties The filepath for the properties file to initialize the
- * ParamicsControlManager.<br>
- * ATMSProperties The filepath for the properties file to initialize the
- * ATMSManager.<br>
- * MediaProperties The filepath for the properties file to initialize the
- * MediaManager.<br>
- * ErrorFile The filename of the error file used for logging errors.<br>
- * ----------------------------------------------------------------------------<br>
- * Example File:<br>
- * CADClientPort = 4444<br>
- * CoordinatorRMIPort = 4445<br>
- * CMSDiversionXML = ../data/cmsdiversions.xml<br>
- * AudioFileLocation = ../audio/<br>
- * ParamicsProperties = ../config/paramics.properties<br>
- * ATMSProperties = ../config/atms.properties<br>
- * MediaProperties = ../config/media.properties<br>
- * ErrorFile = cad_sim_error.xml<br>
- * </code>
- *
- * @author Matthew Cechini (mcechini@calpoly.edu) jdalbey
+ * @author Matthew Cechini (mcechini@calpoly.edu)
+ * @author John Dalbey (jdalbey@calpoly.edu)
  * @version $Date: 2009/04/17 16:27:46 $ $Revision: 1.5 $
  */
@@ -69,5 +46,5 @@
 {
 
-    private static String CONFIG_FILE_NAME = "cad_simulator_config.properties";
+    private static String CONFIG_FILE_NAME = "cad_server.properties";
     /**
      * Error logger.
@@ -76,5 +53,5 @@
 
     /**
      * Enumeration containing properties name values. See CADSimulator class
      * description for more information.
      *
@@ -149,5 +126,5 @@
     /** NOTE: Protected fields are accessed by Coordinator */
     /**
-     * CADSimulatorViewer instance.
+     * CADServerViewer instance.
      */
     protected static CADViewer theViewer;
@@ -189,5 +166,5 @@
     
     /**
-     * Properties file for the CADSimulator.
+     * Properties file for the CADServer, read from CONFIG_FILE_NAME.
      */
     private Properties cadServerProperties;
@@ -211,9 +188,9 @@
             cadServerProperties = new Properties();
             cadServerProperties.load(new FileInputStream(propertiesFile));
-            cadSimLogger.logp(Level.INFO, "CADSimulator", "Constructor",
+            cadSimLogger.logp(Level.INFO, "CADServer", "Constructor",
                     "Properties loaded from " + propertiesFile);
         } catch (Exception e)
         {
-            cadSimLogger.logp(Level.SEVERE, "CADSimulator", "Constructor",
+            cadSimLogger.logp(Level.SEVERE, "CADServer", "Constructor",
                     "Exception in reading properties file.", e);
             JOptionPane.showMessageDialog(new JWindow(), e.getMessage() +
@@ -233,5 +210,5 @@
             if (userInterfaceName == null)
             {
-                cadSimLogger.logp(Level.SEVERE, "CADSimulator", "Constructor",
+                cadSimLogger.logp(Level.SEVERE, "CADServer", "Constructor",
                         propertiesFile + " missing property for user interface.");
                 throw new SimulationException(SimulationException.PROPERTY_MISSING_ERROR);
@@ -244,5 +221,5 @@
             } catch (Exception exc)
             {
-                cadSimLogger.logp(Level.SEVERE, "CADSimulator", "Constructor",
+                cadSimLogger.logp(Level.SEVERE, "CADServer", "Constructor",
                         "Unable to instantiate user interface: " + userInterfaceName
                         + " " + exc);
@@ -257,5 +234,5 @@
             if (simTimeFilename == null)
             {
-                cadSimLogger.logp(Level.SEVERE, "CADSimulator", "Constructor",
+                cadSimLogger.logp(Level.SEVERE, "CADServer", "Constructor",
                         propertiesFile + " missing property for " + CAD_PROPERTIES.ELAPSED_TIME_FILE.name);
                 throw new SimulationException(SimulationException.PROPERTY_MISSING_ERROR);
@@ -267,5 +244,5 @@
             if (commentLogname == null)
             {
-                cadSimLogger.logp(Level.SEVERE, "CADSimulator", "Constructor",
+                cadSimLogger.logp(Level.SEVERE, "CADServer", "Constructor",
                         propertiesFile + " missing property for " + CAD_PROPERTIES.CAD_COMMENTS_LOG.name);
                 throw new SimulationException(SimulationException.PROPERTY_MISSING_ERROR);
@@ -317,5 +294,5 @@
         } catch (RemoteException e)
         {
-            cadSimLogger.logp(Level.SEVERE, "CADSimulator", "Constructor",
+            cadSimLogger.logp(Level.SEVERE, "CADServer", "Constructor",
                     "Exception in starting Coordinator.", e);
 
@@ -336,5 +313,5 @@
         } catch (Exception e)
         {
-            cadSimLogger.logp(Level.SEVERE, "CADSimulator", "Constructor",
+            cadSimLogger.logp(Level.SEVERE, "CADServer", "Constructor",
                     "Exception in parsing CMSDiversion xml file.", e);
 
@@ -472,5 +449,5 @@
         } catch (Exception e)
         {
-            cadSimLogger.logp(Level.SEVERE, "CADSimulator", "Main",
+            cadSimLogger.logp(Level.SEVERE, "CADServer", "Main",
                     "Error initializing application.", e);
 
@@ -27,41 +27,18 @@
 
 /**
- * CADSimulator is main class for the CAD Simulator application. At construction
- * the Coordinator, CoordinatorViewer, and all CAD Simulator Managers are
+ * CADServer is main class for the CAD Simulator application. 
+ * CADServer must be running before starting any other components of the TMCSim.
+ * At construction the Coordinator, CoordinatorViewer, and all CAD Simulator Managers are
  * initialized and data relationships are established. Simulation control is
@@ -27,41 +27,18 @@
  * initialized and data relationships are established. Simulation control is
- * managed through the Coordinator and Managers. The CADSimulator contains the
+ * managed through the Coordinator and Managers. The CADServer contains the
  * instances of all Manager Objects that are used to control the Simulation flow
  * of data.<br>
@@ -76,5 +53,5 @@
 
     /**
-     * Enumeration containing properties name values. See CADSimulator class
+     * Enumeration containing properties name values. See CADServer class
      * description for more information.
      *
